==> php-8.3.16.tar.xz: php-8.3.16/Zend/zend_constants.stub.php <==
<?php

/** @generate-class-entries */

/**
 * @var int
 * @cvalue E_ERROR
 */
const E_ERROR = UNKNOWN;

/**
 * @var int
 * @cvalue E_WARNING
 */
const E_WARNING = UNKNOWN;

/**
 * @var int
 * @cvalue E_PARSE
 */
const E_PARSE = UNKNOWN;

/**
 * @var int
 * @cvalue E_NOTICE
 */
const E_NOTICE = UNKNOWN;

/**
 * @var int
 * @cvalue E_CORE_ERROR
 */
const E_CORE_ERROR = UNKNOWN;

/**
 * @var int
 * @cvalue E_CORE_WARNING
 */
const E_CORE_WARNING = UNKNOWN;

/**
 * @var int
 * @cvalue E_COMPILE_ERROR
 */
const E_COMPILE_ERROR = UNKNOWN;

/**
 * @var int
 * @cvalue E_COMPILE_WARNING
 */
const E_COMPILE_WARNING = UNKNOWN;

/**
 * @var int
 * @cvalue E_USER_ERROR
 */
const E_USER_ERROR = UNKNOWN;

/**
 * @var int
 * @cvalue E_USER_WARNING
 */
const E_USER_WARNING = UNKNOWN;

/**
 * @var int
 * @cvalue E_USER_NOTICE
 */
const E_USER_NOTICE = UNKNOWN;

/**
 * @var int
 * @cvalue E_STRICT
 */
const E_STRICT = UNKNOWN;

/**
 * @var int
 * @cvalue E_RECOVERABLE_ERROR
 */
const E_RECOVERABLE_ERROR = UNKNOWN;

/**
 * @var int
 * @cvalue E_DEPRECATED
 */
const E_DEPRECATED = UNKNOWN;

/**
 * @var int
 * @cvalue E_USER_DEPRECATED
 */
const E_USER_DEPRECATED = UNKNOWN;

/**
 * @var int
 * @cvalue E_ALL
 */
const E_ALL = UNKNOWN;

/**
 * @var int
 * @cvalue DEBUG_BACKTRACE_PROVIDE_OBJECT
 */
const DEBUG_BACKTRACE_PROVIDE_OBJECT = UNKNOWN;
/**
 * @var int
 * @cvalue DEBUG_BACKTRACE_IGNORE_ARGS
 */
const DEBUG_BACKTRACE_IGNORE_ARGS = UNKNOWN;
/**
 * @var bool
 * @cvalue ZTS_V
 */
const ZEND_THREAD_SAFE = UNKNOWN;
/**
 * @var bool
 * @cvalue ZEND_DEBUG
 */
const ZEND_DEBUG_BUILD = UNKNOWN;

/* Special constants true/false/null.  */

/** @var bool */
const TRUE = true;
/** @var bool */
const FALSE = false;
/** @var null */
const NULL = null;

==> php-8.4.17.tar.xz: php-8.4.17/Zend/zend_constants.stub.php <==
<?php

/** @generate-class-entries */

/**
 * @var int
 * @cvalue E_ERROR
 */
const E_ERROR = UNKNOWN;

/**
 * @var int
 * @cvalue E_WARNING
 */
const E_WARNING = UNKNOWN;

/**
 * @var int
 * @cvalue E_PARSE
 */
const E_PARSE = UNKNOWN;

/**
 * @var int
 * @cvalue E_NOTICE
 */
const E_NOTICE = UNKNOWN;

/**
 * @var int
 * @cvalue E_CORE_ERROR
 */
const E_CORE_ERROR = UNKNOWN;

/**
 * @var int
 * @cvalue E_CORE_WARNING
 */
const E_CORE_WARNING = UNKNOWN;

/**
 * @var int
 * @cvalue E_COMPILE_ERROR
 */
const E_COMPILE_ERROR = UNKNOWN;

/**
 * @var int
 * @cvalue E_COMPILE_WARNING
 */
const E_COMPILE_WARNING = UNKNOWN;

/**
 * @var int
 * @cvalue E_USER_ERROR
 */
const E_USER_ERROR = UNKNOWN;

/**
 * @var int
 * @cvalue E_USER_WARNING
 */
const E_USER_WARNING = UNKNOWN;

/**
 * @var int
 * @cvalue E_USER_NOTICE
 */
const E_USER_NOTICE = UNKNOWN;

/**
 * @var int
 * @cvalue E_STRICT
 * @deprecated
 * @todo Remove in PHP 9.0
 */
const E_STRICT = UNKNOWN;

/**
 * @var int
 * @cvalue E_RECOVERABLE_ERROR
 */
const E_RECOVERABLE_ERROR = UNKNOWN;

/**
 * @var int
 * @cvalue E_DEPRECATED
 */
const E_DEPRECATED = UNKNOWN;

/**
 * @var int
 * @cvalue E_USER_DEPRECATED
 */
const E_USER_DEPRECATED = UNKNOWN;

/**
 * @var int
 * @cvalue E_ALL
 */
const E_ALL = UNKNOWN;

/**
 * @var int
 * @cvalue DEBUG_BACKTRACE_PROVIDE_OBJECT
 */
const DEBUG_BACKTRACE_PROVIDE_OBJECT = UNKNOWN;
/**
 * @var int
 * @cvalue DEBUG_BACKTRACE_IGNORE_ARGS
 */
const DEBUG_BACKTRACE_IGNORE_ARGS = UNKNOWN;
/**
 * @var bool
 * @cvalue ZTS_V
 */
const ZEND_THREAD_SAFE = UNKNOWN;
/**
 * @var bool
 * @cvalue ZEND_DEBUG
 */
const ZEND_DEBUG_BUILD = UNKNOWN;

/* Special constants true/false/null.  */

/**
 * @var bool
 * @undocumentable
 */
const TRUE = true;
/**
 * @var bool
 * @undocumentable
 */
const FALSE = false;
/**
 * @var null
 * @undocumentable
 */
const NULL = null;
